import React, {
  FunctionComponent,
  useCallback,
  useEffect,
  useRef,
  useState,
} from 'react';
import { ColumnInstance, Row } from 'react-table';
import EditIcon from '@material-ui/icons/Edit';
import { IconButton } from '@material-ui/core';
import ClearIcon from '@material-ui/icons/Clear';
import styles from 'EditableCell/EditableCell.module.scss';
import tableStyles from 'EnhancedTable.module.scss';
import { useDispatch } from 'react-redux';
import { setTableSelectable } from 'store/actions';
import DoneRoundedIcon from '@material-ui/icons/DoneRounded';
import { Autocomplete } from '@material-ui/lab';
import AppTextField from 'TextField/AppTextField';

type Props = {
  value: string[];
  row: Row<any>;
  column: ColumnInstance<any>;
  options: Array<any>;
  label?: string;
  valueKey?: string;
  labelKey?: string;
};
// Create an editable cell renderer
const EditableCellSelectMultipleField: FunctionComponent<Props> = (
  props: Props
) => {
  const dispatch = useDispatch();
  const setSelectable = useCallback(
    (value: boolean) => {
      dispatch(setTableSelectable(value));
    },
    [dispatch]
  );

  const {
    value: initialValue,
    column,
    row,
    label,
    options,
    valueKey = 'value',
    labelKey = 'label',
  } = props;

  const inputEl = useRef<HTMLInputElement>(null);
  const divEl = useRef<HTMLInputElement>(null);
  const [open, setOpen] = useState(false);
  // We need to keep and update the state of the cell normally
  const [listLabel, setListLabel] = React.useState(initialValue);
  const [listValue, setListValue] = React.useState<string[]>([]);
  useEffect(() => {
    if (inputEl.current) {
      inputEl.current.focus();
    }
  }, [open, inputEl]);

  const setEdit = () => {
    setOpen(true);
    setSelectable(true);
  };

  const updateData = () => {
    if (column.editData) {
      column.editData(row.original, listValue);
    }
    setOpen(false);
    setSelectable(false);
  };

  function cancel() {
    setListLabel(initialValue);
    setOpen(false);
    setSelectable(false);
  }

  useEffect(() => {
    if (open) {
      setListLabel(initialValue);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [open]);

  const submitForm = (event: React.FormEvent) => {
    event.preventDefault();
    updateData();
    setSelectable(false);
  };

  return (
    <div className={styles.cellWrap} ref={divEl}>
      {!open ? (
        <div className={styles.dflex}>
          <span>{label || initialValue} </span>
          <IconButton
            className={tableStyles.displayOnHover}
            size="small"
            onClick={() => setEdit()}
          >
            <EditIcon color="primary" fontSize="small" />
          </IconButton>
        </div>
      ) : (
        <form className={styles.multipleSelect} onSubmit={submitForm}>
          <div className={styles.inputContainer}>
            <Autocomplete
              classes={{
                root: styles.autocompleteRoot,
                inputRoot: styles.autocompleteInputRoot,
                input: styles.autocompleteInput,
              }}
              value={options.filter(
                (item) => listLabel.indexOf(item[labelKey]) > -1
              )}
              multiple
              options={options}
              disableClearable
              getOptionLabel={(option) => option[labelKey]}
              renderInput={(params) => (
                <AppTextField
                  classes={{
                    root: styles.autocompleteTextForm,
                  }}
                  {...params}
                  autoFocus={true}
                  InputLabelProps={{ required: true }}
                />
              )}
              onChange={(event, listLabel: any) => {
                setListLabel(
                  (listLabel as any[]).reduce<string[]>(
                    (acc, item) => [...acc, item[labelKey]],
                    []
                  )
                );
                setListValue(
                  (listLabel as any[]).reduce<string[]>(
                    (acc, item) => [...acc, item[valueKey]],
                    []
                  )
                );
              }}
              clearOnBlur={true}
              freeSolo={true}
              size="small"
              openOnFocus={true}
            />
            <span className={styles.formButton}>
              <IconButton size="small" onClick={updateData}>
                <DoneRoundedIcon color="primary" fontSize="small" />
              </IconButton>
              <IconButton size="small" onClick={() => cancel()}>
                <ClearIcon color="primary" fontSize="small" />
              </IconButton>
            </span>
          </div>
        </form>
      )}
    </div>
  );
};

export default EditableCellSelectMultipleField;
