import React, { useEffect, useState } from 'react';
import { ColumnInstance } from 'react-table';
import AppAsyncPaginateSelect from 'components/Autocomplete/AppAsyncPaginateSelect';
import { TPageLoadResponse, TPageParams } from 'AppModels';

type Props<T> = {
  column: ColumnInstance<any>;
  title?: string;
  valueKey?: string;
  labelKey?: string;
  fetchDataFn: (
    search: string,
    pageParams?: TPageParams
  ) => Promise<TPageLoadResponse<Array<T>>>;
  getDefaultOptionFn: (id: string) => Promise<T>;
};
function AsyncAutoColumnFilter<T extends Record<string, any>>(props: Props<T>) {
  const {
    column,
    fetchDataFn,
    title,
    valueKey = 'id',
    labelKey = 'name',
    getDefaultOptionFn,
  } = props;
  const label = title || column.Header || column.id || '';
  const { filterValue, setFilter } = column;
  const [value, setValue] = useState<Record<string, any> | null>(null);

  useEffect(() => {
    if (!filterValue) {
      setValue(null);
    }
  }, [filterValue]);

  useEffect(
    () => {
      if (filterValue) {
        getDefaultOptionFn(filterValue).then((data) => {
          const newVar = (data as Record<string, any>)?.[labelKey] || '';
          setValue({
            [valueKey]: filterValue,
            [labelKey]: newVar,
          });
        });
      }
    },
    // eslint-disable-next-line react-hooks/exhaustive-deps
    []
  );
  return (
    <AppAsyncPaginateSelect
      className={'text-4'}
      fetchDataFn={fetchDataFn}
      value={value}
      setValue={(option) => {
        setFilter(option?.[valueKey] || undefined);
        setValue(option);
      }}
      valueKey={valueKey}
      labelKey={labelKey}
      label={label}
      placeholder={'ALL'}
    />
  );
}

export default AsyncAutoColumnFilter;
