import { TextField } from '@material-ui/core';
import React, { FunctionComponent } from 'react';
import { DatePicker } from '@material-ui/pickers';
import { getDatabaseFormatType } from 'utils/moment';
import styles from './Filter.module.scss';

type Props = {
  filterValue: any;
  setFilter: (value: any) => void;
  title: string;
  valueKey?: string;
  labelKey?: string;
};

const DatetimePickerFilter: FunctionComponent<Props> = (props: Props) => {
  const { filterValue, setFilter } = props;
  const yearFilterValue =
    filterValue === undefined
      ? null
      : getDatabaseFormatType(filterValue as string, 'YYYY');
  const [year, setYear] = React.useState<string | null>(yearFilterValue);
  return (
    <div className={styles.yearPicker}>
      <DatePicker
        views={['year']}
        label="Year"
        value={year}
        onChange={(newValueYear) => {
          setYear(getDatabaseFormatType(newValueYear as string, 'YYYY'));
          setFilter(getDatabaseFormatType(newValueYear as string, 'YYYY'));
        }}
        renderInput={(props) => (
          <TextField {...props} helperText={false} autoFocus={true} />
        )}
      />
    </div>
  );
};

export default React.memo(DatetimePickerFilter);
