import React, { FunctionComponent } from 'react';
import {
  TableOptions,
  useFilters,
  useRowSelect,
  useSortBy,
  useTable,
} from 'react-table';
import MaUTable from '@material-ui/core/Table';
import { TableBody, TableCell, TableHead, TableRow } from '@material-ui/core';
import styles from './EnhancedTable.module.scss';
import clsx from 'clsx';
import selectionHook from 'plugins/selectionHook';

type Props = TableOptions<any> & {
  useSelection?: boolean;
};

const SimpleLocalTable: FunctionComponent<Props> = (props) => {
  const { columns, data } = props;
  const {
    getTableProps,
    getTableBodyProps,
    headerGroups,
    rows,
    prepareRow,
  } = useTable(
    {
      columns,
      data,
    },
    useFilters,
    useSortBy,
    ...(props.useSelection ? [useRowSelect, selectionHook] : [])
  );
  return (
    <div className={styles.tableBodyScroll}>
      <MaUTable {...getTableProps()}>
        <TableHead>
          {headerGroups.map((headerGroup, index) => (
            <TableRow {...headerGroup.getHeaderGroupProps()}>
              {headerGroup.headers.map((column, index) => {
                return (
                  <TableCell
                    {...column.getHeaderProps(column.getSortByToggleProps())}
                  >
                    <span className={styles.headerCell}>
                      <span>{column.render('Header')}</span>
                      {column.canSort && (
                        <span className={styles.sortColumn}>
                          {column.isSorted ? (
                            column.isSortedDesc ? (
                              <span className={styles.down} />
                            ) : (
                              <span className={styles.up} />
                            )
                          ) : (
                            <React.Fragment>
                              <span className={styles.up} />
                              <span className={styles.down} />
                            </React.Fragment>
                          )}
                        </span>
                      )}
                    </span>
                  </TableCell>
                );
              })}
            </TableRow>
          ))}
        </TableHead>
        <TableBody {...getTableBodyProps()}>
          {rows.map((row, i) => {
            prepareRow(row);
            return (
              <TableRow
                {...row.getRowProps()}
                className={clsx(row.isSelected && styles.selected)}
              >
                {row.cells.map((cell) => {
                  return (
                    <TableCell {...cell.getCellProps()}>
                      {cell.render('Cell')}
                    </TableCell>
                  );
                })}
              </TableRow>
            );
          })}
        </TableBody>
      </MaUTable>
    </div>
  );
};

export default SimpleLocalTable;
