import React, { FunctionComponent, useState } from 'react';
import { TableInstance } from 'react-table';
import { Button, Popover } from '@material-ui/core';
import styles from 'EnhancedTable.module.scss';
import AppFilterIcon from 'assets/icons/AppFilterIcon';
import clsx from 'clsx';

type Props = {
  instance: TableInstance<any>;
  stableColumns: Array<string>;
};
const FilterBox: FunctionComponent<Props> = (props) => {
  const { allColumns, state, setAllFilters } = props.instance;
  const filterLength = state.filters.length;
  const hasFilter = !!allColumns.filter((column) => column.filter).length;
  const [anchorEl, setAnchorEl] = React.useState<HTMLButtonElement | null>(
    null
  );

  const [hidden, setHidden] = useState(true);

  const handleClick = (event: React.MouseEvent<HTMLButtonElement>) => {
    setAnchorEl(event.currentTarget);
    setHidden(false);
  };

  const handleClose = () => {
    setHidden(true);
  };

  function resetFilter() {
    setAllFilters([]);
  }

  const open = Boolean(anchorEl);

  return hasFilter ? (
    <React.Fragment>
      <span className={styles.action} onClick={handleClick}>
        <AppFilterIcon className={styles.iconFilter} />
        <span>FILTER {filterLength > 0 && '(' + filterLength + ')'}</span>
      </span>
      <Popover
        className={clsx(hidden && 'hidden')}
        open={open}
        anchorEl={anchorEl}
        onClose={handleClose}
        anchorOrigin={{
          vertical: 'bottom',
          horizontal: 'left',
        }}
        transformOrigin={{
          vertical: 'top',
          horizontal: 'left',
        }}
      >
        <div className={clsx(styles.popover, styles.filterPopover)}>
          <div className={styles.filterLabel}>
            <span>
              Applied Filters: <strong>{filterLength}</strong>{' '}
            </span>
            {filterLength > 0 && (
              <Button
                className={styles.resetBtn}
                onClick={resetFilter}
                variant="contained"
                color={'primary'}
              >
                Remove
              </Button>
            )}
          </div>
          <div className={styles.filterContent}>
            {allColumns
              .filter((columns) => columns.filter)
              .sort((a, b) => {
                const x = a.filterOrder || 0;
                const y = b.filterOrder || 0;
                // @ts-ignore
                return !x - !y || +(x > y) || -(x < y);
              })
              .map((column) => (
                <div className={styles.filterItem} key={column.id}>
                  {column.render('Filter')}
                </div>
              ))}
          </div>
        </div>
      </Popover>
    </React.Fragment>
  ) : null;
};

export default React.memo(FilterBox);
