import { actions, Hooks, TableInstance, TableState } from 'react-table';
import { useEffect } from 'react';

/**

/**
 * Modified part
 * Add function setSticky for column
 */
function useInstance(instance: TableInstance) {
  const {
    tableKey,
    state: { hiddenColumns, columnOrder, columnResizing },
  } = instance;

  useEffect(() => {
    localStorage.setItem(
      tableKey + '_hiddenColumns',
      JSON.stringify(hiddenColumns)
    );
  }, [hiddenColumns, tableKey]);

  useEffect(() => {
    localStorage.setItem(
      tableKey + '_columnOrder',
      JSON.stringify(columnOrder)
    );
  }, [tableKey, columnOrder]);

  useEffect(() => {
    localStorage.setItem(
      tableKey + '_columnResizing',
      JSON.stringify(columnResizing)
    );
  }, [tableKey, columnResizing]);
}

function reducer(
  state: TableState,
  action: any,
  previousState: TableState,
  instance: TableInstance
) {
  const getDefaultResizingColumns = () => {
    const storageColumns: string[] = localStorage.getItem(
      `${instance.tableKey}_columnResizing`
    )
      ? JSON.parse(
          localStorage.getItem(`${instance.tableKey}_columnResizing`) as string
        )
      : undefined;
    if (storageColumns && typeof storageColumns === 'object')
      return storageColumns;

    return {
      columnWidths: {},
    };
  };

  if (action.type === actions.init) {
    return {
      ...state,
      columnResizing: getDefaultResizingColumns(),
    };
  }

  if (action.type === actions.resetResize) {
    return {
      ...state,
      columnResizing: getDefaultResizingColumns(),
    };
  }
}

export const useLocalStorageTable = (hooks: Hooks<any>) => {
  hooks.useInstance.push(useInstance);

  // @ts-ignore
  hooks.stateReducers.push(reducer);
};

useLocalStorageTable.pluginName = 'useLocalStorageTable';
