import { useHistory, useLocation } from 'react-router-dom';
import { getRouterQueries } from 'utils/router';
import qs from 'qs';
import pickBy from 'lodash/pickBy';
import identity from 'lodash/identity';
import isEqual from 'lodash/isEqual';
import get from 'lodash/get';

export default function useUrlHelpers() {
  const location = useLocation();
  const history = useHistory();

  function getCurrentQuery() {
    return getRouterQueries(location.search);
  }

  function appendQuery(query: Record<string, any>) {
    const currentQuery = getCurrentQuery();
    let newQuery = { ...currentQuery, ...query };
    newQuery = pickBy(newQuery, identity);

    if (isEqual(newQuery, currentQuery)) {
      return;
    }

    const search = '?' + qs.stringify(newQuery);
    history.push({
      search: search,
    });
  }

  function getQueryByKey(key: string) {
    return get(getCurrentQuery(), key) || '';
  }

  return {
    getCurrentQuery,
    appendQuery,
    getQueryByKey,
  };
}
